@@ -379,11 +379,26 @@ sub clone {
         _content => \%orig,
     );
 
+
     $out->set(\%p) if keys %p;
 
+    # warn 'waaaat ' . $out->as_string;
+
     $out;
 }
 
+=head2 as_hash
+
+Dump out a hash(ref) of the parameter instance, depending on the
+calling context.
+
+=cut
+
+sub as_hash {
+    my %out = %{$_[0]->_content};
+    wantarray ? %out : \%out;
+}
+
 =head2 as_where_clause
 
 Generates a data structure suitable to pass into L<SQL::Abstract>
@@ -639,7 +654,8 @@ a link.
 
 sub make_uri {
     my ($self, $uri) = @_;
-    $uri  = $uri->canonical;
+    # looks like URI.pm has made canonical no longer always clone
+    $uri  = $uri->clone->canonical;
     my $q = $self->as_string;
     undef $q if defined $q and $q eq '';
     $uri->query($q);
